@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2020 Dave M
+# ClamTk, copyright (C) 2004-2021 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -63,7 +63,7 @@ sub show_window {
     $window->set_position( 'mouse' );
 
     my $hb = Gtk3::HeaderBar->new;
-    $hb->set_title( _( 'Schedule' ) );
+    $hb->set_title( _( 'Analysis' ) );
     $hb->set_show_close_button( TRUE );
     $hb->set_decoration_layout( 'menu:close' );
 
@@ -79,6 +79,25 @@ sub show_window {
     $hb->pack_start( $button );
     $window->set_titlebar( $hb );
 
+    my $help_message = _(
+        "This section allows you to check the status of a file from Virustotal. If a file has been previously submitted, you will see the results of the scans from dozens of antivirus and security vendors. This allows you to make a more informed decision about the safety of a file.
+
+If the file has never been submitted to Virustotal, you can submit it yourself. When you resubmit the file minutes later, you should see the results.
+
+Please note you should never submit sensitive files to Virustotal.  Any uploaded file can be viewed by Virustotal customers. Do not submit anything with personal information or passwords.
+
+https://www.virustotal.com/gui/home/search"
+    );
+
+    my $help_btn  = Gtk3::ToolButton->new();
+    my $use_image = ClamTk::Icons->get_image( 'system-help' );
+    $help_btn->set_label( _( 'Help' ) );
+    $help_btn->set_icon_name( $use_image );
+    $help_btn->set_is_important( TRUE );
+    $help_btn->set_tooltip_text( _( 'What is this?' ) );
+    $help_btn->signal_connect( clicked => sub { popup( $help_message ) } );
+    $hb->pack_start( $help_btn );
+
     my $box = Gtk3::Box->new( 'vertical', 5 );
     $box->set_homogeneous( FALSE );
     $window->get_content_area->add( $box );
