@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2020 Dave M
+# ClamTk, copyright (C) 2004-2021 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -67,7 +67,7 @@ sub start_gui {
     $eb->add( $top_box );
 
     $hb->set_title( _( 'Virus Scanner' ) );
-    $hb->set_decoration_layout( 'menu:minimize,close' );
+    $hb->set_decoration_layout( 'menu,icon:minimize,close' );
     $hb->set_show_close_button( TRUE );
 
     my $separator = Gtk3::SeparatorToolItem->new;
@@ -579,10 +579,11 @@ sub select_file {
         'gtk-ok'     => 'ok',
     );
     $dialog->set_select_multiple( FALSE );
-    if ( ClamTk::Prefs->get_preference( 'ScanHidden' ) ) {
-        $dialog->set_show_hidden( TRUE );
-    }
     $dialog->set_position( 'center-on-parent' );
+
+    # FALSE until there is an option to change it
+    $dialog->set_show_hidden( FALSE );
+
     if ( 'ok' eq $dialog->run ) {
         $window->queue_draw;
         Gtk3::main_iteration while Gtk3::events_pending;
@@ -609,7 +610,8 @@ sub select_file {
 
 sub select_directory {
     my $directory = '';
-    my $dialog    = Gtk3::FileChooserDialog->new(
+
+    my $dialog = Gtk3::FileChooserDialog->new(
         _( 'Select a directory' ), $window,
         'select-folder',
         'gtk-cancel' => 'cancel',
@@ -617,9 +619,8 @@ sub select_directory {
     );
     $dialog->set_position( 'center-on-parent' );
     $dialog->set_current_folder( ClamTk::App->get_path( 'directory' ) );
-    if ( ClamTk::Prefs->get_preference( 'ScanHidden' ) ) {
-        $dialog->set_show_hidden( TRUE );
-    }
+    $dialog->set_show_hidden( FALSE );
+
     if ( 'ok' eq $dialog->run ) {
         $directory = $dialog->get_filename;
         Gtk3::main_iteration while Gtk3::events_pending;
@@ -711,7 +712,7 @@ sub about {
     $dialog->set_logo( $pixbuf );
     $dialog->set_translator_credits(
         'Please see the credits.md for full listing' );
-    $dialog->set_copyright( "\x{a9} Dave M 2004 - 2020" );
+    $dialog->set_copyright( "\x{a9} Dave M 2004 - 2021" );
     $dialog->set_program_name( 'ClamTk' );
     $dialog->set_authors( [ 'Dave M', 'dave.nerd@gmail.com' ] );
     $dialog->set_comments(
