@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2020 Dave M
+# ClamTk, copyright (C) 2004-2021 Dave M
 #
 # This file is part of ClamTk
 # (https://gitlab.com/dave_m/clamtk-gtk3/).
@@ -170,7 +170,8 @@ sub filter {
     $use_image = 'gtk-cancel';
     $bottombar->add_button( $use_image, HATE_GNOME_SHELL );
     if ( $show ) {
-        $use_image = ClamTk::Icons->get_image( 'preferences-system' );
+        # $use_image = ClamTk::Icons->get_image( 'preferences-system' );
+        $use_image = ClamTk::Icons->get_image( 'document-properties' );
         $bottombar->add_button( $use_image, DESTROY_GNOME_SHELL );
     }
     $bottombar->signal_connect(
@@ -216,7 +217,6 @@ sub filter {
             'smb4k',
             "/run/user/$ENV{USER}/gvfs",
             "$ENV{HOME}/.gvfs" ) {
-                # warn "excluding $m\n";
                 $directive .= " --exclude-dir=$m";
     }
     #>>>
@@ -239,14 +239,13 @@ sub filter {
         $directive .= " --exclude-dir=^" . quotemeta( $ignore );
     }
 
-    # Remove mail directories for now -
-    # until we can parse them... sigh.
+    # Remove mail directories and some backup directories for now.
     # Not all of these can be appended to $HOME for a more
     # specific path - kmail (e.g.) is somewhere
     # under $HOME/.kde/blah/foo/...
     my @maildirs = qw(
         .thunderbird	.mozilla-thunderbird
-        Mail	kmail   evolution
+        Mail	kmail   evolution   timeshift
     );
     for my $mailbox ( @maildirs ) {
         # warn "excluding mailbox directory $mailbox\n";
@@ -289,10 +288,8 @@ sub filter {
         if (   ( $version <=> '101' ) == 0
             || ( $version <=> '101' ) == 1 )
         {
-            $directive
-                .= ' --detect-pua --alert-broken'
-                . ' --alert-macros --alert-encrypted-archive'
-                . ' --alert-encrypted-doc';
+            $directive .= ' --detect-pua --alert-broken'
+            . ' --alert-macros';
         } else {
             $directive .= ' --detect-pua --algorithmic-detection';
         }
@@ -300,14 +297,13 @@ sub filter {
         if (   ( $version cmp '101' ) == 0
             || ( $version cmp '101' ) == 1 )
         {
-            $directive
-                =~ s/\s--detect-pua --alert-broken --alert-macros --alert-encrypted-archive --alert-encrypted-doc'//;
+            $directive =~ s/\s--detect-pua --alert-broken --alert-macros'//;
         } else {
             $directive =~ s/\s--detect-pua --algorithmic-detection//;
         }
     }
 
-    # remove the hidden files if chosen:
+    # Heuristic scanning
     if ( $prefs{ Heuristic } ) {
         # By default, if included, == yes
         $directive .= ' --heuristic-alerts=yes';
@@ -464,19 +460,13 @@ sub scan {
         # These aren't necessarily clean (despite the variable's name)
         # - we just don't want them counted as viruses
         my $clean_words = join( '|',
-            'OK',
-            'Zip module failure',
-            "RAR module failure",
-            'Encrypted.RAR',
-            'Encrypted.Zip',
-            'Empty file',
-            'Excluded',
-            'Input/Output error',
-            'Files number limit exceeded',
-            'handler error',
-            'Broken.Executable',
-            'Oversized.Zip',
-            'Symbolic link' );
+            'OK',                 'Zip module failure',
+            "RAR module failure", 'Encrypted.PDF',
+            'Encrypted.RAR',      'Encrypted.Zip',
+            'Empty file',         'Excluded',
+            'Input/Output error', 'Files number limit exceeded',
+            'handler error',      'Broken.Executable',
+            'Oversized.Zip',      'Symbolic link' );
 
         if ( $status !~ /$clean_words/ ) {    # a virus
             $found->{ $found_count }->{ name }   = $file;
@@ -569,6 +559,7 @@ sub bad_popup {
 
 sub logit {
     my $db_total = ClamTk::App->get_sigtool_info( 'count' );
+    # warn "in Scan: db_total = >$db_total<\n";
     my $REPORT;    # filehandle for histories log
 
     #<<<
